# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.26
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.installers_api import InstallersApi


class TestInstallersApi(unittest.TestCase):
    """InstallersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InstallersApi()

    def tearDown(self) -> None:
        pass

    def test_create_app_installer(self) -> None:
        """Test case for create_app_installer

        create an app installer
        """
        pass

    def test_delete_app_installer(self) -> None:
        """Test case for delete_app_installer

        delete an app installer
        """
        pass

    def test_get_app_installer(self) -> None:
        """Test case for get_app_installer

        get an app installer
        """
        pass

    def test_installer_create_install(self) -> None:
        """Test case for installer_create_install

        create an app install from an installer
        """
        pass

    def test_installer_get_install(self) -> None:
        """Test case for installer_get_install

        get an installer install
        """
        pass

    def test_render_app_installer(self) -> None:
        """Test case for render_app_installer

        render an app installer
        """
        pass

    def test_update_app_installer(self) -> None:
        """Test case for update_app_installer

        update an app installer
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.models.app_docker_build_component_config import AppDockerBuildComponentConfig

class TestAppDockerBuildComponentConfig(unittest.TestCase):
    """AppDockerBuildComponentConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppDockerBuildComponentConfig:
        """Test AppDockerBuildComponentConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppDockerBuildComponentConfig`
        """
        model = AppDockerBuildComponentConfig()
        if include_optional:
            return AppDockerBuildComponentConfig(
                build_args = [
                    ''
                    ],
                component_config_connection_id = '',
                connected_github_vcs_config = nuon.models.app/connected_github_vcs_config.app.ConnectedGithubVCSConfig(
                    branch = '', 
                    component_config_id = '', 
                    component_config_type = '', 
                    created_at = '', 
                    created_by_id = '', 
                    directory = '', 
                    id = '', 
                    repo = '', 
                    repo_name = '', 
                    repo_owner = '', 
                    updated_at = '', 
                    vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                        created_at = '', 
                        created_by_id = '', 
                        github_install_id = '', 
                        id = '', 
                        updated_at = '', 
                        vcs_connection_commit = [
                            nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                author_email = '', 
                                author_name = '', 
                                component_config_connection_id = '', 
                                created_at = '', 
                                created_by_id = '', 
                                id = '', 
                                message = '', 
                                sha = '', 
                                updated_at = '', )
                            ], ), 
                    vcs_connection_id = '', ),
                created_at = '',
                created_by_id = '',
                dockerfile = '',
                env_vars = {
                    'key' : ''
                    },
                id = '',
                public_git_vcs_config = nuon.models.app/public_git_vcs_config.app.PublicGitVCSConfig(
                    branch = '', 
                    component_config_id = '', 
                    component_config_type = '', 
                    created_at = '', 
                    created_by_id = '', 
                    directory = '', 
                    id = '', 
                    repo = '', 
                    updated_at = '', ),
                target = '',
                updated_at = ''
            )
        else:
            return AppDockerBuildComponentConfig(
        )
        """

    def testAppDockerBuildComponentConfig(self):
        """Test AppDockerBuildComponentConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
